// Description:
// this is a simple Arduino project which uses an AM2320 temperature/humidity
// sensor to read temperature and humidity; temperature and humidity
// are sent to the host PC via the serial connection and displayed in 
// a terminal; this is essentially the "test" example that comes with the
// Adafruit library: https://github.com/adafruit/Adafruit_AM2320

// HW Connections:
// we'll use an I2C connector on the base-board of the Arduino Nano 33 BLE Sense
// board to connect to AM2320 sensor, which talks I2C!
//  _________________
// |                 |
// | AM2320 Sensor   | Front view (see thru) of AM2320 sensor
// |  1   2   3  4   |
// | VDD SDA GND SCL |
//  -----------------
//    |   |   |   |
//    |   |   |   |
//                ^I2C clock in, requires a pullup of 2-10K to VDD
//            ^this is signal/power ground
//        ^I2C data in/out, requires a pullup of 2-10K to VDD
//    ^this is power in, can be 3-5VDC

#include "Adafruit_Sensor.h"
#include "Adafruit_AM2320.h"

Adafruit_AM2320 am2320 = Adafruit_AM2320();

void setup()
{
  // create serial connection; 
  Serial.begin(9600);
  while (!Serial) {
    delay(10); // hang out until serial port opens
  }

  Serial.println("Adafruit AM2320 Basic Test");
  am2320.begin();
}

void loop()
{
  Serial.print("Temp: "); 
  Serial.print(am2320.readTemperature());
  delay(100);
  Serial.print(" Hum: "); 
  Serial.println(am2320.readHumidity());
  
  // wait 2 seconds between measurements;
  delay(1900);
}
